\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{dhbwtarticle}[LaTeX Template for DHBW Scientific Articles]
\RequirePackage{xcolor}
\RequirePackage[all]{background}
\RequirePackage{tikz}

% Define colors
\definecolor{dhgreen}{HTML}{46812b}
\definecolor{titlegray}{HTML}{576771}
\definecolor{subsecgray}{HTML}{5c6871}  % Unused.

\LoadClass[10pt,parskip=half]{scrartcl}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax

\fontfamily{phv}
\renewcommand{\rmdefault}{phv} % Arial
\renewcommand{\sfdefault}{phv} % Arial

% Provide multi-language support
\providecommand*{\classyearname}{Year of}
\providecommand*{\keywordsname}{Keywords}
\AtBeginDocument{
	\@ifpackagewith{babel}{english}{\addto\captionsenglish{%
			\renewcommand*\classyearname{Year of}
			\renewcommand*\keywordsname{Keywords}
	}}{}
	\@ifpackagewith{babel}{ngerman}{\addto\captionsngerman{
			\renewcommand*\classyearname{Jahrgang}
			\renewcommand*\abstractname{Kurzfassung}
			\renewcommand*\keywordsname{Schüsselwörter}
	}}{}
}

% Extra input fields
\newcommand*{\courseofstudies}[1]{%
	\newcommand{\@courseofstudies}{#1}
}

\newcommand*{\company}[1]{%
	\newcommand{\@company}{#1}
}

\newcommand*{\class}[1]{%
	\newcommand{\@class}{#1}
}

\newcommand*{\projectname}[1]{%
	\newcommand{\@projectname}{#1}
}

\newcommand*{\classyear}[1]{%
	\newcommand{\@classyear}{#1}
}

\renewcommand{\abstract}[1]{%
	\textbf{\abstractname:}~#1
}

\newcommand*{\keywords}[1]{%
	\textbf{\keywordsname:}~#1
}

% New command to make the emphasized text green.
\newcommand{\emphasis}[1]{{\color{dhgreen}#1}}

% Commands for cross-referencing
\newcommand{\tabref}[1]{\textbf{\tablename~\ref{#1}}}
\newcommand{\secref}[1]{\textbf{\chaptername~\ref{1}}}
\newcommand{\figref}[1]{\textbf{\figurename~\ref{#1}}}
\newcommand{\eqref}[1]{Gl.~(\ref{#1})}
\newcommand{\lstref}[1]{\textbf{Listing}~\ref{#1}}

% Definition of page layout and margins
\usepackage[%
left=2cm,
top=2cm,
right=1.75cm,
bottom=2cm,
footskip=1cm,
]{geometry}

% Redefine how the title is rendered.
\renewcommand{\maketitle}{%
	\begin{center}
		\color{titlegray}
		{\renewcommand{\baselinestretch}{1.2}\selectfont\fontsize{16pt}{20pt}\bfseries\expandafter\MakeUppercase\expandafter{\@title}}\\ \medskip
		\@author\\
		\@courseofstudies, \@class, \@company
	\end{center}
}

% Formating of sections, captions and footnotes etc.
\setkomafont{section}{\selectfont\bfseries\color{dhgreen}}
\addtokomafont{section}{\MakeUppercase}
\setkomafont{subsection}{\selectfont\bfseries\color{titlegray}}
\setkomafont{caption}{\fontsize{9}{10.8}\normalfont}
\setkomafont{captionlabel}{\fontsize{9}{10.8}\normalfont\bfseries}
\setkomafont{footnote}{\fontsize{9}{10.8}\normalfont}
\renewcommand{\footnotesize}{\fontsize{9}{10.8}}

% Großbuchstaben in Titel und Überschriften
\RedeclareSectionCommand[
%runin=false,
afterindent=false,
beforeskip=24pt,
afterskip=12pt]{section}
\RedeclareSectionCommand[
%runin=false,
afterindent=false,
beforeskip=12pt,
afterskip=12pt]{subsection}

% Header, footer and page numbering
\usepackage[plainheadsepline, headsepline]{scrlayer-scrpage}
\addtokomafont{headsepline}{\color{titlegray}}
\clearpairofpagestyles
\ohead*{\@projectname\ -- \classyearname~\@classyear}
\addtokomafont{pageheadfoot}{\upshape}
%\ofoot[\pagemark]{\hspace*{2cm}\pagemark}
\ofoot[\pagemark]{%
	\begin{tikzpicture}[remember picture, overlay] 
		%\node[anchor=center] at (current page.south east)++(-1cm,1cm) {\pagemark}
		\node[align=center, anchor=center] at (1cm,0) {\pagemark};
	\end{tikzpicture}
}

% Rectangle in bottom-right corner
\SetBgContents{\tikz[remember picture, overlay] \fill[fill=dhgreen] (current page.south east)++(0,20mm) rectangle ++(-12mm,49mm);}
\SetBgAngle{0}
\SetBgOpacity{1}
\SetBgScale{1}